@@ -2,7 +2,7 @@ package Test2::API::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.302197';
+our $VERSION = '1.302200';
 
 
 use Carp qw/confess croak/;
@@ -436,7 +436,6 @@ sub note {
 sub diag {
     my $self = shift;
     my ($message) = @_;
-    my $hub = $self->{+HUB};
     $self->send_event(
         'Diag',
         message => $message,
@@ -987,7 +986,7 @@ tools, plugins, and other extensions.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/test-more/>.
+L<https://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -1009,11 +1008,11 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
